package wsdclient;

import java.io.IOException;
import javax.xml.soap.SOAPBody;
import javax.xml.soap.SOAPBodyElement;
import javax.xml.soap.SOAPElement;
import javax.xml.soap.SOAPException;
import wsdclient.WSDispatchClient;

public class StandaloneTester {

	private static WSDispatchClient wsdc = null;
	
	/**
	 * Test SOAP services described in .properties files.
	 * 
	 * Values used in properties can be extracted from WSDLs. 
	 * 
	 * Used test services:
	 * <ol>
	 * <li>Calculator, <a href="http://www.service-repository.com/service/overview/877027757">http://www.service-repository.com/service/overview/877027757</a></li>
	 * <li>Perodictable, <a href="http://www.webservicex.net/ws/WSDetails.aspx?WSID=19&CATID=7">http://www.webservicex.net/ws/WSDetails.aspx?WSID=19&CATID=7</a></li>
	 * </ol>
	 * 
	 * args[] examples:
	 * <ul>
	 * <li>"wsdclient/calculator.properties" "Add" "2" "5"</li>
	 * <li>"wsdclient/periodictable.properties" "Atomicnumber" "Iron"</li>
	 * </ul>
	 * 
	 * @param args ".properties filename" "Method( to call from .properties)" "value of placeholder {0} in soapactionMethod" "value of placeholder {1} in soapactionMethod" ...
	 * @throws SOAPException 
	 * @throws IOException 
	 */
	public static void main(String[] args) throws SOAPException, IOException {
		
		if(wsdc == null) { wsdc = new WSDispatchClient(args[0]); }
		
		String request = wsdc.configuration.getProperty("soapmsg" + args[1]);
		for(int i=2; i< args.length; i++) {	request = request.replace("{"+(i-2)+"}", args[i]); }
		System.out.println("REQUEST : " + request + "\nRESPONSE : ");
		
		wsdc.doRequest(request, wsdc.configuration.getProperty("soapaction" + args[1]));
        
        SOAPBody responseBody = wsdc.response.getSOAPBody();
        
    	SOAPBodyElement responseElement = (SOAPBodyElement)responseBody.getChildElements().next();
    	SOAPElement returnElement = (SOAPElement)responseElement.getChildElements().next();
    	if(responseBody.getFault() != null) { //-- If response has any fault.
    		System.out.println("################# SOAP FAULT #########################\n\n" + returnElement.getValue()+" "+responseBody.getFault().getFaultString());
    	}  else  {
    		System.out.println(returnElement.getValue());
    	}
        

	}

    
}
