package wsdclient;

import java.io.File;
import java.io.IOException;
import java.io.StringReader;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.Properties;

import javax.xml.namespace.QName;
import javax.xml.soap.MessageFactory;
import javax.xml.soap.SOAPException;
import javax.xml.soap.SOAPMessage;
import javax.xml.transform.Source;
import javax.xml.transform.stream.StreamSource;
import javax.xml.ws.BindingProvider;
import javax.xml.ws.Dispatch;
import javax.xml.ws.Service;

/**
 * Example webservice client without generated stubs
 */
public class WSDispatchClient {
	
	public Properties configuration;
	protected Service service;
	protected Dispatch<SOAPMessage> dispatch;
	protected BindingProvider bindingProvider;
	public SOAPMessage response;

	public WSDispatchClient(String configurationPropertiesFile) throws IOException {
			 File f = new File(configurationPropertiesFile);
			 Properties properties = new Properties();
			 properties.load(this.getClass().getClassLoader().getResourceAsStream(configurationPropertiesFile));
			 init(properties);
	}
	
	public WSDispatchClient(Properties conf) throws MalformedURLException {
		init(conf);
	}
	
	private void init(Properties conf) throws MalformedURLException {
		
		configuration = conf;
		URL wsdlLocation = new URL(configuration.getProperty("serviceWSDL"));
        QName serviceQName = new QName(configuration.getProperty("serviceNamespace"), configuration.getProperty("serviceName"));
        service = Service.create(wsdlLocation, serviceQName);
        
        if(configuration.getProperty("servicePortNamespace") == null) {
        	configuration.setProperty("servicePortNamespace", configuration.getProperty("serviceNamespace"));
        }
        
        // QName for Port As defined in wsdl.
        QName portQName = new QName(configuration.getProperty("servicePortNamespace"), configuration.getProperty("servicePortName"));

        // Create a dispatch instance
        dispatch = service.createDispatch(portQName, SOAPMessage.class, Service.Mode.MESSAGE);
        
        // Use Dispatch as BindingProvider
        bindingProvider = (BindingProvider) dispatch;
        
	}
	
	public void doRequest(String soapMsg, String soapAction) throws SOAPException {
		
		bindingProvider.getRequestContext().put(BindingProvider.SOAPACTION_URI_PROPERTY, soapAction);
        MessageFactory messageFactory = MessageFactory.newInstance();
        SOAPMessage message = messageFactory.createMessage();
        message.getSOAPPart().setContent((Source) new StreamSource(new StringReader(soapMsg)));
		message.saveChanges();
        response = dispatch.invoke(message);
	}

}
